| Title: | A Datetime Range Picker Widget for Usage in 'Shiny' Applications |
|---|---|
| Description: | Provides a datetime range picker widget for usage in 'Shiny'. It creates a calendar allowing to select a start date and an end date as well as two fields allowing to select a start time and an end time. |
| Authors: | Stéphane Laurent [aut, cre], Wojciech Maj [cph] (author of the 'React-DateTimeRange-Picker' library) |
| Maintainer: | Stéphane Laurent <[email protected]> |
| License: | GPL-3 |
| Version: | 1.1.0 |
| Built: | 2026-05-26 07:41:24 UTC |
| Source: | https://github.com/stla/datetimerangepicker |
A datetime range picker widget for a Shiny UI.
DateTimeRangePickerInput(inputId, from = NULL, to = NULL, style = NULL)DateTimeRangePickerInput(inputId, from = NULL, to = NULL, style = NULL)
inputId |
the input slot that will be used to access the values |
from, to
|
initial values, either |
style |
inline CSS for the container |
An input element that can be included in a Shiny UI definition.
This is a shiny.tag.list object.
library(DateTimeRangePicker) library(shiny) ui <- fluidPage( br(), sidebarLayout( sidebarPanel( width = 5, tags$fieldset( tags$legend("Click to change time"), DateTimeRangePickerInput( "dtrpicker", style = paste0( "background-color: chartreuse; ", "box-shadow: 0 30px 40px 0 rgba(16, 36, 94, 0.2);" ) ) ) ), mainPanel( width = 7, verbatimTextOutput("dtrpicker") ) ) ) server <- function(input, output){ output[["dtrpicker"]] <- renderPrint({ input[["dtrpicker"]] }) } if(interactive()){ shinyApp(ui, server) }library(DateTimeRangePicker) library(shiny) ui <- fluidPage( br(), sidebarLayout( sidebarPanel( width = 5, tags$fieldset( tags$legend("Click to change time"), DateTimeRangePickerInput( "dtrpicker", style = paste0( "background-color: chartreuse; ", "box-shadow: 0 30px 40px 0 rgba(16, 36, 94, 0.2);" ) ) ) ), mainPanel( width = 7, verbatimTextOutput("dtrpicker") ) ) ) server <- function(input, output){ output[["dtrpicker"]] <- renderPrint({ input[["dtrpicker"]] }) } if(interactive()){ shinyApp(ui, server) }
Change the values of a datetime range picker input.
updateDateTimeRangePickerInput(session, inputId, from, to)updateDateTimeRangePickerInput(session, inputId, from, to)
session |
the Shiny |
inputId |
the id of the datetime range picker widget to be updated |
from, to
|
new values for the datetime range picker widget |
No returned value, called for side effect.